@@ -1,7 +1,7 @@
 package Data::Dmp;
 
-our $DATE = '2014-12-28'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-01-02'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -72,6 +72,14 @@ sub _dump {
     }
 
     my $class;
+
+    if ($ref eq 'Regexp' || $ref eq 'REGEXP') {
+        require re;
+        my ($pat, $mod) = re::regexp_pattern($val);
+        $pat =~ s|(?<!\\)(\\\\)*/|$1\\/|g; # escape non-escaped slashes
+        return "qr/$pat/$mod";
+    }
+
     if (blessed $val) {
         $class = $ref;
         $ref = reftype($val);
@@ -153,7 +161,7 @@ Data::Dmp - Dump Perl data structures
 
 =head1 VERSION
 
-This document describes version 0.05 of Data::Dmp (from Perl distribution Data-Dmp), released on 2014-12-28.
+This document describes version 0.06 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-01-02.
 
 =head1 SYNOPSIS
 
@@ -260,7 +268,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
